#
# Makefile Template for Tessy
# Compiler   : MPLAB (Microchip Technology Inc.)
# Environment: MPLAB (Microchip Technology Inc.)
#

# Defines to be generated by Tessy:
#
# TESSY_SYS					:=
# MODULE_PATH				:=
# TESTOBJECT				:=
# USER_LINK_OPTIONS		:=
# COMPILER_INSTALL_PATH	:=
# TARGET_INSTALL_PATH	:=

#####################################################################
#BEGIN_DEFINES
#####################################################################

# CPU           := dsPIC33FJ256GP710
TESSY_SYS_DOS   := $(shell cygpath -w $(TESSY_SYS))
MODULE_PATH_DOS := $(shell cygpath -w $(MODULE_PATH))
MPLAB_HOME      := $(shell ts_pathname -s '$(COMPILER_INSTALL_PATH)')
LINK_FILE_SHORT := $(shell ts_pathname -s '$(LINKER_FILE)')
TARGET_OPTIONS  := -DTS_DSPIC

TS_NAME         := TS_MPLAB
IDE_NAME        := mplab
COMPANY_NAME    := microchip
PROCESSOR_NAME  := dspic

ifeq ("little","$(ENDIANESS)")
  TS_BYTEORDER := TS_HOST_BYTEORDER
endif
ifeq ("big","$(ENDIANESS)")
  TS_BYTEORDER := TS_NET_BYTEORDER
  TS_BYTEORDER_OPTION :=
endif
ifndef TS_BYTEORDER
  $(error Attribute 'Endianess' has invalid value '$(ENDIANESS)', only 'little' and 'big' are allowed.)
endif

all	 : check_success master slave

# Cygwin work around.
S_BUILDIN_TESSY_FLAG := $(wildcard $(MODULE_PATH)/tslows_builtin.tessy)

check_success :
ifneq ($(S_BUILDIN_TESSY_FLAG),)
	@echo *
	@echo * Obviously the last build failed. Cleaning up built-in files...
	@-rm -f "$(MODULE_PATH)"/tslows_builtin.*
	@echo * Please, try again to generate a built-in target binary.
	@echo *
	@exit 1
endif


#
# MASTER & COMM Makefiles
# (you should not need to modify these settings)
#
M_COMM_MAKE     := $(TESSY_SYS)/make/master_$(IDE_NAME)_gnu_i386.mk
S_COMM_MAKE     := $(TESSY_SYS)/src/comm/comm_$(IDE_NAME)_$(COMPANY_NAME)_$(PROCESSOR_NAME).mk


#
#
# SLAVE
#
S_CC            := $(MPLAB_HOME)\bin\pic30-gcc.exe
S_LINK          := $(MPLAB_HOME)\bin\pic30-gcc.exe
S_INCLUDES      := -I$(TESSY_SYS_DOS)\include\tessy\comm -I$(MODULE_PATH_DOS)
S_STUB_OBJECT   := $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_stubs$(OBJECT_POSTFIX)
S_UC_OBJECT     := $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_usr$(OBJECT_POSTFIX)
S_COMP_OPTIONS  := -I"$(MPLAB_HOME)\h" -mcpu=$(CPU) -c -DTESSY -DTS_SLAVE -DTS_HAVE_INT64 -D$(TS_NAME) $(TARGET_OPTIONS) -g
S_LINK_OPTIONS  := -Wl,-L"$(MPLAB_HOME)\lib",--script="$(LINK_FILE_SHORT)",--defsym=__ICD2RAM=1,--heap=512,--no-check-sections,-Map="$(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s.map"

#####################################################################
#END_DEFINES
#####################################################################

# Targets to be defined by Tessy
#
# for each source
#
# S_SRC_OBJECTS      := $(MODULE_PATH_DOS)\ts_src*$(OBJECT_POSTFIX)
# USER_COMP_OPTIONS* :=
# S_C1_OBJECTS       := $(MODULE_PATH)/ts_c1c01$(OBJECT_POSTFIX) ... ts_c1cnn.$(OBJECT_POSTFIX)
#
# $(MODULE_PATH_DOS)\ts_src*$(OBJECT_POSTFIX) : $(MODULE_PATH_DOS)\ts_src*.c
#     $(S_CC) $(S_INCLUDES) $(S_COMP_OPTIONS) $(USER_COMP_OPTIONS) -C -o"$@" $<
#
# $(MODULE_PATH)/ts_c1c*$(OBJECT_POSTFIX) : $(MODULE_PATH)/ts_c1c*.c
#     $(S_CC) $(S_INCLUDES) $(S_COMP_OPTIONS) $(USER_COMP_OPTIONS) -C -o"$@" $<
#
#####################################################################
#BEGIN_TARGETS
#####################################################################

ifneq ($(S_GenerateBuiltinData),)
TARGET_FLAG := d
BUILTIN_OBJ := $(MODULE_PATH_DOS)\tslows_builtin$(OBJECT_POSTFIX)
master :
	@-rm -f "$(MODULE_PATH)"/tslows_builtin$(OBJECT_POSTFIX)
else
BUILTIN_OBJ :=
TARGET_FLAG := s
master : $(MODULE_PATH)/ts_$(TESTOBJECT)_m.exe
endif
slave  : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_$(TARGET_FLAG)$(BINARY_POSTFIX)

# COMPILE USERCODE / STUBS
#
$(S_UC_OBJECT) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_usr.c
	$(S_CC) $(S_INCLUDES) $(S_COMP_OPTIONS) -o"$@" $<

$(S_STUB_OBJECT) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_stubs.c
	$(S_CC) $(S_INCLUDES) $(S_COMP_OPTIONS) -o"$@" $<


#
# COMPILE/LINK MASTER
#

include $(M_COMM_MAKE)


#
# COMPILE SLAVE COMMUNICATION MODULES

include $(S_COMM_MAKE)


#
#
# COMPILE/LINK SLAVE
#
$(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(OBJECT_POSTFIX) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s.c
	@echo *
	@echo ***** Compiling Slave *****
	$(S_CC) -o"$@" $(S_COMP_OPTIONS) $(S_INCLUDES) $<


$(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_$(TARGET_FLAG)$(BINARY_POSTFIX): $(BUILTIN_OBJ) $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(OBJECT_POSTFIX) \
										$(S_SRC_OBJECTS) \
										$(S_UC_OBJECT) \
										$(S_STUB_OBJECT) \
										$(S_C1_OBJECTS) \
										$(S_OBJECTS)
	@echo *
	@echo ***** Linking Slave *****
	$(S_LINK) $(S_LINK_OPTIONS) $(USER_LINK_OPTIONS) \
				 $(S_OBJECTS) $(BUILTIN_OBJ) $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(OBJECT_POSTFIX) \
				 $(S_SRC_OBJECTS) $(S_UC_OBJECT) \
				 $(S_STUB_OBJECT) $(S_C1_OBJECTS)  -o"$@"
ifneq ($(S_GenerateBuiltinData),)
	@-rm -f "$(MODULE_PATH)"/tslows_builtin.*
	@echo *
	@echo * Generated target binary '$(MODULE_PATH)/ts_$(TESTOBJECT)_$(TARGET_FLAG)$(BINARY_POSTFIX)' containing builtin data.
	@echo *
endif	

#####################################################################
#END_TARGETS
#####################################################################
